import fs from 'node:fs';
import path from 'node:path';
import { pathsafeTimestamp } from './pathsafeTimestamp.js';
export async function avoidOverwrite(filePath, strategy = AddSequence, force = false) {
    if (force || fs.existsSync(filePath)) {
        return await strategy(filePath);
    }
    return filePath;
}
export const AddTimestamp = async (filenamePath) => {
    const base = path.basename(filenamePath);
    const dir = path.dirname(filenamePath);
    return path.join(dir, `${pathsafeTimestamp()}-${base}`);
};
export const AddSequence = async (filenamePath) => {
    const ext = path.extname(filenamePath);
    const base = path.basename(filenamePath, ext);
    const dir = path.dirname(filenamePath);
    const n = fs
        .readdirSync(dir)
        .filter((fileName) => fileName.startsWith(base))
        .filter((fileName) => new RegExp(`_\\d+${ext}`).test(fileName))
        .map((other) => parseInt(other
        .match(new RegExp(`_(\\d+)${ext === '' ? '' : `\\${ext}`}$`))
        ?.slice(1)
        .shift() || '0'))
        .reduce((max, i) => Math.max(max, i), 0);
    return path.join(dir, `${base}_${n + 1}${ext}`);
};
//# sourceMappingURL=avoidOverwrite.js.map