import chalk from 'chalk';
import cliProgress from 'cli-progress';
export class ProgressBar {
    multibar;
    bar;
    constructor({ value = 0, max }) {
        this.multibar = new cliProgress.MultiBar({
            format: `{bar} {percentage}% {eta_formatted} ${chalk.yellow('{caption}')}`,
            barCompleteChar: '█',
            barIncompleteChar: '█',
            autopadding: true,
            autopaddingChar: '   ',
            formatBar: (progress, options) => {
                const completeSize = Math.round(progress * options.barsize);
                const incompleteSize = options.barsize - completeSize;
                return (chalk.green(options.barCompleteString.substring(0, completeSize)) +
                    options.barGlue +
                    chalk.gray.dim(options.barIncompleteString.substring(0, incompleteSize)));
            }
        });
        this.bar = this.multibar.create(max, value);
        this.bar.update({ caption: '' });
    }
    increment() {
        this.bar.increment();
    }
    caption(caption) {
        this.bar.update({
            caption: caption.substring(0, 24) + (caption.length > 24 ? '…' : '')
        });
    }
    stop() {
        this.multibar.stop();
    }
}
//# sourceMappingURL=ProgressBar.js.map