import cli from '@battis/qui-cli';
import { EventEmitter } from 'node:events';
const AWAITING = true;
const cache = {};
const ready = new EventEmitter();
ready.setMaxListeners(1000);
export async function get(url, downloader) {
    url = normalizeURL(url);
    if (url in cache) {
        if (cache[url] === AWAITING) {
            return new Promise((resolve) => {
                ready.on(url, () => resolve(cache[url]));
            });
        }
        return cache[url];
    }
    else {
        cache[url] = AWAITING;
        cache[url] = await downloader();
        ready.emit(url);
        return cache[url];
    }
}
function normalizeURL(url) {
    const normalized = url
        .replace(/^(\/.+\?.*)(w|h)=\dpx&?(.*)$/, '$1$3')
        .replace(/\?$/, '');
    if (normalized !== url) {
        cli.log.debug(`${cli.colors.url(url)} normalized to ${cli.colors.url(normalized)}`);
    }
    return normalized;
}
//# sourceMappingURL=Cache.js.map