import PQueue from 'p-queue';
import * as common from '../../common.js';
import * as Cache from './Cache.js';
import * as AuthenticatedFetch from './Downloader/AuthenticatedFetch.js';
import * as HTTPFetch from './Downloader/HTTPFetch.js';
// TODO Downloader needs to honor --concurrentThreads
export class Downloader {
    auth;
    http;
    host;
    queue;
    constructor({ host, outputOptions, ...options }) {
        const { outputPath } = outputOptions;
        const { concurrentThreads } = options;
        if (!outputPath) {
            throw new common.Output.OutputError('Downloader requires outputPath');
        }
        this.host = host;
        this.queue = new PQueue({ concurrency: concurrentThreads });
        this.auth = new AuthenticatedFetch.Downloader({
            host,
            outputOptions,
            ...options
        });
        this.http = new HTTPFetch.Downloader({
            outputPath,
            ...options
        });
    }
    async download(original, filename) {
        // TODO Cache.Item typing
        // @ts-expect-error 2346 conflict between DownloadItem and DownloadError
        return await Cache.get(original, async () => {
            let fetchUrl = original;
            if (fetchUrl.slice(0, 2) == '//') {
                fetchUrl = `https:${fetchUrl}`;
            }
            else if (fetchUrl.slice(0, 1) == '/') {
                fetchUrl = `https://${this.host}${fetchUrl}`;
            }
            if (/myschoolcdn\.com\/.+\/video\//.test(fetchUrl)) {
                fetchUrl = fetchUrl.replace(/(\/\d+)\/video\/video\d+_(\d+)\.(.+)/, '$1/$2/1/video.$3');
            }
            let strategy = this.http;
            if (/ftpimages/.test(fetchUrl)) {
                strategy = this.auth;
            }
            return {
                original,
                accessed: new Date(),
                ...(await this.queue.add(() => strategy.download(fetchUrl, filename)))
            };
        });
    }
    async quit() {
        await this.auth.close();
    }
}
//# sourceMappingURL=Downloader.js.map