import cli from '@battis/qui-cli';
import * as common from '../../../common.js';
import { ContentDisposition, filenameFromDisposition } from '../filenameFromDisposition.js';
export class Downloader {
    outputPath;
    logRequests;
    constructor({ outputPath, logRequests }) {
        this.outputPath = outputPath;
        this.logRequests = logRequests;
    }
    async download(url, filename) {
        cli.log.debug(`HTTPFetch: ${cli.colors.url(url)}`);
        const response = await fetch(url);
        if (this.logRequests) {
            cli.log.debug({
                url,
                response: {
                    url: response.url,
                    redirected: response.redirected,
                    type: response.type,
                    ok: response.ok,
                    status: response.status,
                    statusText: response.statusText,
                    headers: response.headers
                }
            });
        }
        if (response.ok && response.body) {
            return {
                localPath: await common.Output.writeFetchedFile({
                    url,
                    stream: response.body,
                    outputPath: this.outputPath
                }),
                filename: filename ||
                    filenameFromDisposition({
                        url,
                        value: response.headers.get(ContentDisposition) || undefined
                    })
            };
        }
        else {
            return { error: `${response.status}: ${response.statusText}` };
        }
    }
}
//# sourceMappingURL=HTTPFetch.js.map