import cli from '@battis/qui-cli';
import { api } from 'datadirect-puppeteer';
import * as common from '../../../common.js';
import * as Base from './Base.js';
const studentDataContentTypes = ['Roster'];
let possibleContent = undefined;
async function getPossibleContent(leadSectionId) {
    if (!possibleContent) {
        possibleContent = await api.datadirect.GroupPossibleContentGet({
            payload: {
                format: 'json',
                leadSectionId
            }
        });
    }
    return possibleContent;
}
export const snaphot = async ({ session, groupId: Id, payload = { format: 'json' }, ignoreErrors = true, studentData, logRequests }) => {
    common.Debug.withGroupId(Id, 'Start capturing bulletin board');
    try {
        const BulletinBoard = [];
        await getPossibleContent(Id);
        const items = await api.datadirect.BulletinBoardContentGet({
            session,
            payload: {
                format: 'json',
                sectionId: Id,
                associationId: 1,
                pendingInd: false
            },
            logRequests
        });
        for (const item of items) {
            const ContentType = possibleContent.find((e) => e.ContentId == item.ContentId);
            try {
                if (ContentType &&
                    studentDataContentTypes.includes(ContentType.Content) &&
                    !studentData) {
                    throw new Base.StudentDataError();
                }
                BulletinBoard.push({
                    ...item,
                    ContentType,
                    Content: await api.datadirect.BulletinBoardContent_detail(item, possibleContent, {
                        session,
                        payload: { ...payload, contextValue: Id, contextLabelId: 2 },
                        pathParams: { Id },
                        logRequests
                    })
                });
            }
            catch (error) {
                BulletinBoard.push({
                    ...item,
                    ContentType,
                    Content: { error: error.message }
                });
                if (!(error instanceof Base.StudentDataError)) {
                    if (ignoreErrors) {
                        common.Debug.errorWithGroupId(Id, `Error capturing bulletin board {ContentId: ${cli.colors.value(item.ContentId)}, ContentType: ${cli.colors.quotedValue(`"${ContentType?.Content}"`)}`, error);
                    }
                    else {
                        throw error;
                    }
                }
            }
        }
        common.Debug.withGroupId(Id, 'Bulletin board captured');
        return BulletinBoard;
    }
    catch (error) {
        if (ignoreErrors) {
            common.Debug.errorWithGroupId(Id, 'Error capturing bulletin board', error);
            return undefined;
        }
        else {
            throw error;
        }
    }
};
//# sourceMappingURL=BulletinBoard.js.map