import { api } from 'datadirect-puppeteer';
import * as common from '../../../common.js';
import * as Base from './Base.js';
export const snapshot = async ({ groupId: sectionId, ignoreErrors, studentData, ...options }) => {
    common.Debug.withGroupId(sectionId, 'Start capturing gradebook');
    try {
        const markingPeriods = await api.datadirect.GradeBookMarkingPeriodList({
            ...options,
            payload: { sectionId }
        });
        const Gradebook = [];
        for (const markingPeriod of markingPeriods) {
            const entry = {
                markingPeriod,
                gradebook: await api.gradebook.hydrategradebook({
                    ...options,
                    payload: {
                        sectionId,
                        markingPeriodId: markingPeriod.MarkingPeriodId
                    }
                })
            };
            if (!studentData) {
                entry.gradebook.Roster = { error: new Base.StudentDataError().message };
            }
            Gradebook.push(entry);
        }
        common.Debug.withGroupId(sectionId, 'Gradebook captured');
        return Gradebook;
    }
    catch (error) {
        if (ignoreErrors) {
            common.Debug.errorWithGroupId(sectionId, 'Error capturing gradebook', error);
            return undefined;
        }
        else {
            throw error;
        }
    }
};
//# sourceMappingURL=GradeBook.js.map